# Changelog

<!--next-version-placeholder-->

## v2.4.0 (2023-03-09)
### Feature
* Updated spacy dependencies to include 3.5.0 ([`cd016e2`](https://github.com/centre-for-humanities-computing/DaCy/commit/cd016e2179c4c3073718f99301499001e0ff2af7))

### Documentation
* Update augmenty dependency for docs ([`ce0e7d6`](https://github.com/centre-for-humanities-computing/DaCy/commit/ce0e7d626006d849d97a5a78d0f4505c6c260f15))
* Remove NERDA from tests it is no longer maintained. ([`cc1d8e8`](https://github.com/centre-for-humanities-computing/DaCy/commit/cc1d8e82d756f0fd56c6d94ec92c87510810e2e2))

## v2.3.2 (2023-02-14)
### Fix
* Allow ner model to handle long sequences ([`243867d`](https://github.com/centre-for-humanities-computing/DaCy/commit/243867daf0c873a7b59ee6d7459c4a0446332eca))
* Update aggregation strategy to follow recommendation by the creator ([`17ed355`](https://github.com/centre-for-humanities-computing/DaCy/commit/17ed3551c1898d5c5028fce9534b0166177e6c67))

### Documentation
* Update formatting ([`38fc982`](https://github.com/centre-for-humanities-computing/DaCy/commit/38fc98238b5608486a0d816db2131ebdfd204123))

## v2.3.1 (2023-01-09)
### Fix
* Update about.py ([#178](https://github.com/centre-for-humanities-computing/DaCy/issues/178)) ([`e548c82`](https://github.com/centre-for-humanities-computing/DaCy/commit/e548c8218f8612173948ef2f423024ddf950109a))

### Documentation
* Fixed markdown link in .rst file ([`fe424be`](https://github.com/centre-for-humanities-computing/DaCy/commit/fe424bebdb5b92c1b9af8f9c99a5ed4e4a00f68c))
* Added news ([`d648ac1`](https://github.com/centre-for-humanities-computing/DaCy/commit/d648ac10d139ff20fa4fe32a98acc65ec6c88ec5))

## v2.3.0 (2023-01-05)
### Feature
* Added scandi-ner model to dacy ([`dc2a514`](https://github.com/centre-for-humanities-computing/DaCy/commit/dc2a51491eba86c480c000c6707e6a4c572feae5))
* Added scandi-ner model to dacy ([`a2bec3b`](https://github.com/centre-for-humanities-computing/DaCy/commit/a2bec3bc43296aeb4b7f9059e9123ed48b18e5c2))

### Documentation
* Added news ([`f5b64da`](https://github.com/centre-for-humanities-computing/DaCy/commit/f5b64dae0925bd8d7709c29238d860f9297bf761))
* Added news ([`ed991b8`](https://github.com/centre-for-humanities-computing/DaCy/commit/ed991b816da732e1c9bbb5aaa55175597b34fcc7))
* Model was trained by dan nielsen ([`be4471b`](https://github.com/centre-for-humanities-computing/DaCy/commit/be4471bdcaf1ce33f51e0e4e8e4382e53a10f0ea))
* Remove rubbish from changelog ([`35adc3b`](https://github.com/centre-for-humanities-computing/DaCy/commit/35adc3b347600104d68cd03c05b8677078cda6fc))
* Fix minor ([`b363a4e`](https://github.com/centre-for-humanities-computing/DaCy/commit/b363a4e8cb4b7dc0b0e172b24fecde0eac675197))

## v2.2.9 (2023-01-03)
### Fix
* Update huggingface name for wrapped models ([`cbb3f3b`](https://github.com/centre-for-humanities-computing/DaCy/commit/cbb3f3b53454ecb660044037ed1854c278047055))

### Documentation
* Updated github action badge ([`20b6bc9`](https://github.com/centre-for-humanities-computing/DaCy/commit/20b6bc9ca481232220e9b6b2d35683d17bb51889))

## v2.0.2 (2023-01-02)
### Fix
* Fixed parsing error of config str ([`c9ce75b`](https://github.com/centre-for-humanities-computing/DaCy/commit/c9ce75bc4db3cde60f127b463ea6b6bdc1507bf4))

### Documentation
* Updated faq to be semi-package agnostic ([`c1a1c34`](https://github.com/centre-for-humanities-computing/DaCy/commit/c1a1c34d6fd08d243d19dbf78228852878e3d6c3))
* Update links in pyproject.toml ([`4868137`](https://github.com/centre-for-humanities-computing/DaCy/commit/486813788741d894112b5422bbd1d033c522fac5))
* Added missing images to docs ([`535e170`](https://github.com/centre-for-humanities-computing/DaCy/commit/535e17081f080cffad5c104bbff4e771b5053516))
* Fixed broken links ([`069cfe3`](https://github.com/centre-for-humanities-computing/DaCy/commit/069cfe3e793d6bad6be9bed22e86c122a17b4b8e))
* Updated changelog ([`824e3f6`](https://github.com/centre-for-humanities-computing/DaCy/commit/824e3f636ea9d9515909c6bae4211427fdd29855))
* Minor updates ([`34727fe`](https://github.com/centre-for-humanities-computing/DaCy/commit/34727fe086af6f7dfecc8e07d74b029b525575b4))
* Removed built with spacy badge ([`edf6118`](https://github.com/centre-for-humanities-computing/DaCy/commit/edf6118f7121ba6e729a37f4818237c8c384bf14))
* Overhaul of documentation ([`4dd2602`](https://github.com/centre-for-humanities-computing/DaCy/commit/4dd2602b04a9284037c83db6d7f25dbfbea88a17))
* General update ([`583ca73`](https://github.com/centre-for-humanities-computing/DaCy/commit/583ca7348d468badc232083ad17e1fdb21021001))
* Ran notebooks using latest update ([`9fce7fe`](https://github.com/centre-for-humanities-computing/DaCy/commit/9fce7febc0a434a2a6baaf2227741de331c63239))
* Removed faq from readme ([`45e3417`](https://github.com/centre-for-humanities-computing/DaCy/commit/45e341705f3129b8f53fd9cb9b7525bd5d40d44d))
* Moved news and changes to its own section ([`cf3a73a`](https://github.com/centre-for-humanities-computing/DaCy/commit/cf3a73af86cbe2d6aeec040125be394ee30b627e))
* Added documentation for hate-speech models ([`63cd6fe`](https://github.com/centre-for-humanities-computing/DaCy/commit/63cd6fe6fd52a63df431e62bb1672e91b9c9c2f3))
* Fixed typo ([`60f0779`](https://github.com/centre-for-humanities-computing/DaCy/commit/60f0779f74021b86b8ab584fe4137fba3314b7f6))
* Fixes copy-paste error in sentiment docs ([`614117a`](https://github.com/centre-for-humanities-computing/DaCy/commit/614117af65c0b863d4390fd3c4ea573827dfb28c))
* Updated documentation on augmentation ([`1102be1`](https://github.com/centre-for-humanities-computing/DaCy/commit/1102be18fb6d822f883ef9eb695871386215e2df))
* Updated documentation on sentiment ([`6a079cb`](https://github.com/centre-for-humanities-computing/DaCy/commit/6a079cb3e40a785bb24e39936469c3753b157a69))
* Added citation cff ([`b364ca3`](https://github.com/centre-for-humanities-computing/DaCy/commit/b364ca36075e524e6ea4c11984ada43d726cad04))
